package App::relpath;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-07-15'; # DATE
our $DIST = 'App-relpath'; # DIST
our $VERSION = '0.05'; # VERSION

1;
# ABSTRACT: Return the relative pathname

__END__

=pod

=encoding UTF-8

=head1 NAME

App::relpath - Return the relative pathname

=head1 VERSION

This document describes version 0.05 of App::relpath (from Perl distribution App-relpath), released on 2021-07-15.

=head1 SYNOPSIS

See the command-line script L<relpath>.

=head1 CONTRIBUTOR

=for stopwords Steven Haryanto

Steven Haryanto <sharyanto@cpan.org>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-relpath>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-relpath>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-relpath>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<App::realpath>, L<App::quickabspath>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2015, 2014 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
